@@ -28,7 +28,7 @@ https://www.sciencedirect.com/science/article/pii/S2352711020300170
 
 """
 # module level dunders
-__version__ = "4.0.4"
+__version__ = "4.1.2"
 __author__ = "Michael Ortner & Alexandre Boisselet"
 __credits__ = "The Magpylib community"
 __all__ = [
@@ -49,9 +49,10 @@ __all__ = [
 ]
 
 # create interface to outside of package
+from magpylib._src.defaults.defaults_utility import SUPPORTED_PLOTTING_BACKENDS
 from magpylib import magnet, current, misc, core, graphics
 from magpylib._src.defaults.defaults_classes import default_settings as defaults
 from magpylib._src.fields import getB, getH
-from magpylib._src.obj_classes import Sensor
+from magpylib._src.obj_classes.class_Sensor import Sensor
 from magpylib._src.obj_classes.class_Collection import Collection
 from magpylib._src.display.display import show
