@@ -1,16 +1,15 @@
 """Collection class code"""
 # pylint: disable=redefined-builtin
+# pylint: disable=import-outside-toplevel
 from collections import Counter
 
 from magpylib._src.defaults.defaults_utility import validate_style_keys
 from magpylib._src.exceptions import MagpylibBadUserInput
-from magpylib._src.fields.field_wrap_BH_level2 import getBH_level2
+from magpylib._src.fields.field_wrap_BH import getBH_level2
 from magpylib._src.input_checks import check_format_input_obj
 from magpylib._src.obj_classes.class_BaseDisplayRepr import BaseDisplayRepr
 from magpylib._src.obj_classes.class_BaseGeo import BaseGeo
 from magpylib._src.utility import format_obj_input
-from magpylib._src.utility import LIBRARY_SENSORS
-from magpylib._src.utility import LIBRARY_SOURCES
 from magpylib._src.utility import rec_obj_remover
 
 
@@ -25,14 +24,14 @@ def repr_obj(obj, format="type+id+label"):
 
     tag = ""
     if show_type:
-        tag += f"{obj._object_type}"
+        tag += f"{type(obj).__name__}"
 
     if show_label:
         if show_type:
             tag += " "
         label = getattr(getattr(obj, "style", None), "label", None)
         if label is None:
-            label = "nolabel" if show_type else f"{obj._object_type}"
+            label = "nolabel" if show_type else f"{type(obj).__name__}"
         tag += label
 
     if show_id:
@@ -63,7 +62,7 @@ def collection_tree_generator(
 
     children = getattr(obj, "children", [])
     if len(children) > max_elems:  # replace with counter if too many
-        counts = Counter([c._object_type for c in children])
+        counts = Counter([type(c).__name__ for c in children])
         children = [f"{v}x {k}s" for k, v in counts.items()]
 
     props = []
@@ -76,6 +75,7 @@ def collection_tree_generator(
                     "children",
                     "parent",
                     "style",
+                    "field_func",
                     "sources",
                     "sensors",
                     "collections",
@@ -120,9 +120,9 @@ def collection_tree_generator(
 class BaseCollection(BaseDisplayRepr):
     """Collection base class without BaseGeo properties"""
 
-    def __init__(self, *children, override_parent=False):
+    _draw_func = None
 
-        self._object_type = "Collection"
+    def __init__(self, *children, override_parent=False):
 
         BaseDisplayRepr.__init__(self)
 
@@ -327,7 +327,7 @@ class BaseCollection(BaseDisplayRepr):
 
         # assign parent
         for obj in obj_list:
-            if obj._object_type == "Collection":
+            if isinstance(obj, Collection):
                 # no need to check recursively with `collections_all` if obj is already self
                 if obj is self or self in obj.collections_all:
                     raise MagpylibBadUserInput(
@@ -351,16 +351,15 @@ class BaseCollection(BaseDisplayRepr):
         return self
 
     def _update_src_and_sens(self):
-        # pylint: disable=protected-access
         """updates sources, sensors and collections attributes from children"""
-        self._sources = [
-            obj for obj in self._children if obj._object_type in LIBRARY_SOURCES
-        ]
-        self._sensors = [
-            obj for obj in self._children if obj._object_type in LIBRARY_SENSORS
-        ]
+        # pylint: disable=protected-access
+        from magpylib._src.obj_classes.class_BaseExcitations import BaseSource
+        from magpylib._src.obj_classes.class_Sensor import Sensor
+
+        self._sources = [obj for obj in self._children if isinstance(obj, BaseSource)]
+        self._sensors = [obj for obj in self._children if isinstance(obj, Sensor)]
         self._collections = [
-            obj for obj in self._children if obj._object_type == "Collection"
+            obj for obj in self._children if isinstance(obj, Collection)
         ]
 
     def remove(self, *children, recursive=True, errors="raise"):
@@ -488,7 +487,7 @@ class BaseCollection(BaseDisplayRepr):
         for child in self._children:
             # match properties false will try to apply properties from kwargs only if it finds it
             # without throwing an error
-            if child._object_type == "Collection" and recursive:
+            if isinstance(child, Collection) and recursive:
                 self.__class__.set_children_styles(child, style_kwargs, _validate=False)
             style_kwargs_specific = {
                 k: v
@@ -517,7 +516,7 @@ class BaseCollection(BaseDisplayRepr):
             sources, sensors = self, inputs
         return sources, sensors
 
-    def getB(self, *inputs, squeeze=True, pixel_agg=None):
+    def getB(self, *inputs, squeeze=True, pixel_agg=None, output="ndarray"):
         """Compute B-field in [mT] for given sources and observers.
 
         Parameters
@@ -537,9 +536,14 @@ class BaseCollection(BaseDisplayRepr):
             which is applied to observer output values, e.g. mean of all sensor pixel outputs.
             With this option, observers input with different (pixel) shapes is allowed.
 
+        output: str, default='ndarray'
+            Output type, which must be one of `('ndarray', 'dataframe')`. By default a
+            `numpy.ndarray` object is returned. If 'dataframe' is chosen, a `pandas.DataFrame`
+            object is returned (the Pandas library must be installed).
+
         Returns
         -------
-        B-field: ndarray, shape squeeze(m, k, n1, n2, ..., 3)
+        B-field: ndarray, shape squeeze(m, k, n1, n2, ..., 3) or DataFrame
             B-field at each path position (m) for each sensor (k) and each sensor pixel
             position (n1,n2,...) in units of [mT]. Sensor pixel positions are equivalent
             to simple observer positions. Paths of objects that are shorter than m will be
@@ -579,10 +583,11 @@ class BaseCollection(BaseDisplayRepr):
             sumup=False,
             squeeze=squeeze,
             pixel_agg=pixel_agg,
+            output=output,
             field="B",
         )
 
-    def getH(self, *inputs, squeeze=True, pixel_agg=None):
+    def getH(self, *inputs, squeeze=True, pixel_agg=None, output="ndarray"):
         """Compute H-field in [kA/m] for given sources and observers.
 
         Parameters
@@ -602,9 +607,14 @@ class BaseCollection(BaseDisplayRepr):
             which is applied to observer output values, e.g. mean of all sensor pixel outputs.
             With this option, observers input with different (pixel) shapes is allowed.
 
+        output: str, default='ndarray'
+            Output type, which must be one of `('ndarray', 'dataframe')`. By default a
+            `numpy.ndarray` object is returned. If 'dataframe' is chosen, a `pandas.DataFrame`
+            object is returned (the Pandas library must be installed).
+
         Returns
         -------
-        H-field: ndarray, shape squeeze(m, k, n1, n2, ..., 3)
+        H-field: ndarray, shape squeeze(m, k, n1, n2, ..., 3) or DataFrame
             H-field at each path position (m) for each sensor (k) and each sensor pixel
             position (n1,n2,...) in units of [kA/m]. Sensor pixel positions are equivalent
             to simple observer positions. Paths of objects that are shorter than m will be
@@ -644,6 +654,7 @@ class BaseCollection(BaseDisplayRepr):
             sumup=False,
             squeeze=squeeze,
             pixel_agg=pixel_agg,
+            output=output,
             field="H",
         )
 
