@@ -1,36 +1,48 @@
 """Collection of classes for display styling."""
 # pylint: disable=C0302
 # pylint: disable=too-many-instance-attributes
+# pylint: disable=cyclic-import
 import numpy as np
 
 from magpylib._src.defaults.defaults_utility import color_validator
 from magpylib._src.defaults.defaults_utility import get_defaults_dict
 from magpylib._src.defaults.defaults_utility import LINESTYLES_MATPLOTLIB_TO_PLOTLY
 from magpylib._src.defaults.defaults_utility import MagicProperties
-from magpylib._src.defaults.defaults_utility import MAGPYLIB_FAMILIES
 from magpylib._src.defaults.defaults_utility import SUPPORTED_PLOTTING_BACKENDS
 from magpylib._src.defaults.defaults_utility import SYMBOLS_MATPLOTLIB_TO_PLOTLY
 from magpylib._src.defaults.defaults_utility import validate_property_class
 from magpylib._src.defaults.defaults_utility import validate_style_keys
 
 
-def get_style_class(obj):
-    """Returns style instance based on object type. If object has no attribute `_object_type` or is
-    not found in `MAGPYLIB_FAMILIES` returns `BaseStyle` instance.
-    """
-    obj_type = getattr(obj, "_object_type", None)
-    style_fam = MAGPYLIB_FAMILIES.get(obj_type, None)
-    if isinstance(style_fam, (list, tuple)):
-        style_fam = style_fam[0]
-    return STYLE_CLASSES.get(style_fam, BaseStyle)
-
-
 def get_style(obj, default_settings, **kwargs):
     """Returns default style based on increasing priority:
     - style from defaults
     - style from object
     - style from kwargs arguments
     """
+    # pylint: disable=import-outside-toplevel
+    from magpylib._src.obj_classes.class_BaseExcitations import (
+        BaseMagnet as MagpyMagnet,
+    )
+    from magpylib._src.obj_classes.class_BaseExcitations import (
+        BaseCurrent as MagpyCurrent,
+    )
+    from magpylib._src.obj_classes.class_misc_Dipole import Dipole as MagpyDipole
+    from magpylib._src.obj_classes.class_Sensor import Sensor as MagpySensor
+    from magpylib._src.display.traces_generic import MagpyMarkers
+
+    families = {
+        "magnet": MagpyMagnet,
+        "current": MagpyCurrent,
+        "dipole": MagpyDipole,
+        "sensor": MagpySensor,
+        "markers": MagpyMarkers,
+    }
+    obj_family = None
+    for fam, cls in families.items():
+        if isinstance(obj, cls):
+            obj_family = fam
+            break
     # parse kwargs into style an non-style arguments
     style_kwargs = kwargs.get("style", {})
     style_kwargs.update(
@@ -43,18 +55,12 @@ def get_style(obj, default_settings, **kwargs):
     styles_by_family = default_settings.display.style.as_dict()
 
     # construct object specific dictionary base on style family and default style
-    obj_type = getattr(obj, "_object_type", None)
-    obj_families = MAGPYLIB_FAMILIES.get(obj_type, [])
-
     obj_style_default_dict = {
         **styles_by_family["base"],
-        **{
-            k: v
-            for fam in obj_families
-            for k, v in styles_by_family.get(fam, {}).items()
-        },
+        **dict(styles_by_family.get(obj_family, {}).items()),
     }
     style_kwargs = validate_style_keys(style_kwargs)
+
     # create style class instance and update based on precedence
     obj_style = getattr(obj, "style", None)
     style = obj_style.copy() if obj_style is not None else BaseStyle()
@@ -291,7 +297,8 @@ class Model3d(MagicProperties):
             pairs, or a callable returning the equivalent dictionary.
 
         backend: str
-            Plotting backend corresponding to the trace. Can be one of `['matplotlib', 'plotly']`.
+            Plotting backend corresponding to the trace. Can be one of
+            `['generic', 'matplotlib', 'plotly']`.
 
         constructor: str
             Model constructor function or method to be called to build a 3D-model object
@@ -334,7 +341,8 @@ class Trace3d(MagicProperties):
     Parameters
     ----------
     backend: str
-        Plotting backend corresponding to the trace. Can be one of `['matplotlib', 'plotly']`.
+        Plotting backend corresponding to the trace. Can be one of
+        `['generic', 'matplotlib', 'plotly']`.
 
     constructor: str
         Model constructor function or method to be called to build a 3D-model object
@@ -368,7 +376,7 @@ class Trace3d(MagicProperties):
 
     def __init__(
         self,
-        backend=None,
+        backend="generic",
         constructor=None,
         args=None,
         kwargs=None,
@@ -487,14 +495,16 @@ class Trace3d(MagicProperties):
 
     @property
     def backend(self):
-        """Plotting backend corresponding to the trace. Can be one of `['matplotlib', 'plotly']`."""
+        """Plotting backend corresponding to the trace. Can be one of
+        `['generic', 'matplotlib', 'plotly']`."""
         return self._backend
 
     @backend.setter
     def backend(self, val):
-        assert val is None or val in SUPPORTED_PLOTTING_BACKENDS, (
+        backends = ["generic"] + list(SUPPORTED_PLOTTING_BACKENDS)
+        assert val is None or val in backends, (
             f"The `backend` property of {type(self).__name__} must be one of"
-            f"{SUPPORTED_PLOTTING_BACKENDS},\n"
+            f"{backends},\n"
             f"but received {repr(val)} instead."
         )
         self._backend = val
@@ -1604,11 +1614,3 @@ class DisplayStyle(MagicProperties):
     @markers.setter
     def markers(self, val):
         self._markers = validate_property_class(val, "markers", Markers, self)
-
-
-STYLE_CLASSES = {
-    "magnet": MagnetStyle,
-    "current": CurrentStyle,
-    "dipole": DipoleStyle,
-    "sensor": SensorStyle,
-}
