@@ -1,44 +1,28 @@
 import unittest
 
 import numpy as np
-from scipy.spatial.transform import Rotation as R
 
 import magpylib as magpy
 from magpylib._src.exceptions import MagpylibBadUserInput
-from magpylib._src.exceptions import MagpylibInternalError
-from magpylib._src.fields.field_wrap_BH_level1 import getBH_level1
-from magpylib._src.fields.field_wrap_BH_level2 import getBH_level2
-from magpylib._src.fields.field_wrap_BH_level2_dict import getBH_dict_level2
+from magpylib._src.fields.field_wrap_BH import getBH_level2
 from magpylib._src.input_checks import check_format_input_observers
 from magpylib._src.utility import format_obj_input
 from magpylib._src.utility import format_src_inputs
 from magpylib._src.utility import test_path_format as tpf
 
+GETBH_KWARGS = {"sumup": False, "squeeze": True, "pixel_agg": None, "output": "ndarray"}
+
 
 def getBHv_unknown_source_type():
     """unknown source type"""
-    getBH_dict_level2(
-        source_type="badName",
+    getBH_level2(
+        sources="badName",
+        observers=(0, 0, 0),
         magnetization=(1, 0, 0),
         dimension=(0, 2, 1, 0, 360),
         position=(0, 0, -0.5),
-        observers=(1.5, 0, -0.1),
         field="B",
-    )
-
-
-def getBH_level1_internal_error():
-    """bad source_type input should not happen"""
-    x = np.array([(1, 2, 3)])
-    rot = R.from_quat((0, 0, 0, 1))
-    getBH_level1(
-        field="B",
-        source_type="woot",
-        magnetization=x,
-        dimension=x,
-        observers=x,
-        position=x,
-        orientation=rot,
+        **GETBH_KWARGS
     )
 
 
@@ -46,7 +30,15 @@ def getBH_level2_bad_input1():
     """test BadUserInput error at getBH_level2"""
     src = magpy.magnet.Cuboid((1, 1, 2), (1, 1, 1))
     sens = magpy.Sensor()
-    getBH_level2([src, sens], (0, 0, 0), sumup=False, squeeze=True, field="B")
+    getBH_level2(
+        [src, sens],
+        (0, 0, 0),
+        sumup=False,
+        squeeze=True,
+        pixel_agg=None,
+        field="B",
+        output="ndarray",
+    )
 
 
 def getBH_level2_bad_input2():
@@ -59,85 +51,100 @@ def getBH_level2_bad_input2():
     magpy.getB(pm1, [sens1, sens2])
 
 
-def getBH_level2_internal_error1():
-    """somehow an unrecognized objects end up in get_src_dict"""
-    # pylint: disable=protected-access
-    sens = magpy.Sensor()
-    x = np.zeros((10, 3))
-    magpy._src.fields.field_wrap_BH_level2.get_src_dict([sens], 10, 10, x)
-
-
 # getBHv missing inputs ------------------------------------------------------
 def getBHv_missing_input1():
-    """missing bh"""
+    """missing field"""
     x = np.array([(1, 2, 3)])
-    getBH_dict_level2(source_type="Cuboid", observers=x, magnetization=x, dimension=x)
+    # pylint: disable=missing-kwoa
+    getBH_level2(
+        sources="Cuboid", observers=x, magnetization=x, dimension=x, **GETBH_KWARGS
+    )
 
 
 def getBHv_missing_input2():
     """missing source_type"""
     x = np.array([(1, 2, 3)])
-    getBH_dict_level2(bh=True, observers=x, magnetization=x, dimension=x)
+    getBH_level2(observers=x, field="B", magnetization=x, dimension=x, **GETBH_KWARGS)
 
 
 def getBHv_missing_input3():
-    """missing observers"""
+    """missing observer"""
     x = np.array([(1, 2, 3)])
-    getBH_dict_level2(bh=True, source_type="Cuboid", magnetization=x, dimension=x)
+    getBH_level2(
+        sources="Cuboid", field="B", magnetization=x, dimension=x, **GETBH_KWARGS
+    )
 
 
 def getBHv_missing_input4_cuboid():
     """missing Cuboid mag"""
     x = np.array([(1, 2, 3)])
-    getBH_dict_level2(bh=True, source_type="Cuboid", observers=x, dimension=x)
+    getBH_level2(sources="Cuboid", observers=x, field="B", dimension=x, **GETBH_KWARGS)
 
 
 def getBHv_missing_input5_cuboid():
     """missing Cuboid dim"""
     x = np.array([(1, 2, 3)])
-    getBH_dict_level2(bh=True, source_type="Cuboid", observers=x, magnetization=x)
+    getBH_level2(
+        sources="Cuboid", observers=x, field="B", magnetization=x, **GETBH_KWARGS
+    )
 
 
 def getBHv_missing_input4_cyl():
     """missing Cylinder mag"""
     x = np.array([(1, 2, 3)])
     y = np.array([(1, 2)])
-    getBH_dict_level2(bh=True, source_type="Cylinder", observers=x, dimension=y)
+    getBH_level2(
+        sources="Cylinder", observers=x, field="B", dimension=y, **GETBH_KWARGS
+    )
 
 
 def getBHv_missing_input5_cyl():
     """missing Cylinder dim"""
     x = np.array([(1, 2, 3)])
-    getBH_dict_level2(bh=True, source_type="Cylinder", observers=x, magnetization=x)
+    getBH_level2(
+        sources="Cylinder", observers=x, field="B", magnetization=x, **GETBH_KWARGS
+    )
 
 
 def getBHv_missing_input4_sphere():
     """missing Sphere mag"""
     x = np.array([(1, 2, 3)])
-    getBH_dict_level2(bh=True, source_type="Sphere", observers=x, dimension=1)
+    getBH_level2(sources="Sphere", observers=x, field="B", dimension=1, **GETBH_KWARGS)
 
 
 def getBHv_missing_input5_sphere():
     """missing Sphere dim"""
     x = np.array([(1, 2, 3)])
-    getBH_dict_level2(bh=True, source_type="Sphere", observers=x, magnetization=x)
+    getBH_level2(
+        sources="Sphere", observers=x, field="B", magnetization=x, **GETBH_KWARGS
+    )
 
 
 # bad inputs -------------------------------------------------------------------
 def getBHv_bad_input1():
     """different input lengths"""
-    x = np.array([(1, 2, 3)])
+    x = np.array([(1, 2, 3)] * 3)
     x2 = np.array([(1, 2, 3)] * 2)
-    getBH_dict_level2(
-        bh=True, source_type="Cuboid", observers=x, magnetization=x2, dimension=x
+    getBH_level2(
+        sources="Cuboid",
+        observers=x,
+        field="B",
+        magnetization=x2,
+        dimension=x,
+        **GETBH_KWARGS
     )
 
 
 def getBHv_bad_input2():
     """bad source_type string"""
     x = np.array([(1, 2, 3)])
-    getBH_dict_level2(
-        bh=True, source_type="Cubooid", observers=x, magnetization=x, dimension=x
+    getBH_level2(
+        sources="Cubooid",
+        observers=x,
+        field="B",
+        magnetization=x,
+        dimension=x,
+        **GETBH_KWARGS
     )
 
 
@@ -145,8 +152,13 @@ def getBHv_bad_input3():
     """mixed input"""
     x = np.array([(1, 2, 3)])
     s = magpy.Sensor()
-    getBH_dict_level2(
-        bh=True, source_type="Cuboid", observers=s, magnetization=x, dimension=x
+    getBH_level2(
+        sources="Cuboid",
+        observers=s,
+        field="B",
+        magnetization=x,
+        dimension=x,
+        **GETBH_KWARGS
     )
 
 
@@ -249,29 +261,24 @@ class TestExceptions(unittest.TestCase):
 
     def test_except_getBHv(self):
         """getBHv"""
-        self.assertRaises(KeyError, getBHv_missing_input1)
-        self.assertRaises(MagpylibBadUserInput, getBHv_missing_input2)
-        self.assertRaises(MagpylibBadUserInput, getBHv_missing_input3)
-        self.assertRaises(MagpylibBadUserInput, getBHv_missing_input4_cuboid)
-        self.assertRaises(MagpylibBadUserInput, getBHv_missing_input4_cyl)
-        self.assertRaises(MagpylibBadUserInput, getBHv_missing_input4_sphere)
-        self.assertRaises(MagpylibBadUserInput, getBHv_missing_input5_cuboid)
-        self.assertRaises(MagpylibBadUserInput, getBHv_missing_input5_cyl)
-        self.assertRaises(MagpylibBadUserInput, getBHv_missing_input5_sphere)
+        self.assertRaises(TypeError, getBHv_missing_input1)
+        self.assertRaises(TypeError, getBHv_missing_input2)
+        self.assertRaises(TypeError, getBHv_missing_input3)
+        self.assertRaises(TypeError, getBHv_missing_input4_cuboid)
+        self.assertRaises(TypeError, getBHv_missing_input4_cyl)
+        self.assertRaises(TypeError, getBHv_missing_input4_sphere)
+        self.assertRaises(TypeError, getBHv_missing_input5_cuboid)
+        self.assertRaises(TypeError, getBHv_missing_input5_cyl)
+        self.assertRaises(TypeError, getBHv_missing_input5_sphere)
         self.assertRaises(MagpylibBadUserInput, getBHv_bad_input1)
         self.assertRaises(MagpylibBadUserInput, getBHv_bad_input2)
         self.assertRaises(MagpylibBadUserInput, getBHv_bad_input3)
         self.assertRaises(MagpylibBadUserInput, getBHv_unknown_source_type)
 
-    def test_except_getBH_lev1(self):
-        """getBH_level1 exception testing"""
-        self.assertRaises(MagpylibInternalError, getBH_level1_internal_error)
-
     def test_except_getBH_lev2(self):
         """getBH_level2 exception testing"""
         self.assertRaises(MagpylibBadUserInput, getBH_level2_bad_input1)
         self.assertRaises(MagpylibBadUserInput, getBH_level2_bad_input2)
-        self.assertRaises(MagpylibInternalError, getBH_level2_internal_error1)
 
     def test_except_bad_input_shape_basegeo(self):
         """BaseGeo bad input shapes"""
